clear; close all;

% flowctl - Controls the flow of the analysis script
%{
flowctl = 'estimate';
flowctl = 'plot guess';
flowctl = 'plot previous estimate';
flowctl = 'previous estimate as guess';
%}
flowctl = 'estimate';
analysis_name = 'parent_metabolite_d1030';

% Compiling the system to make sure the 
% latest changes have been committed. 
build_system

% Setting up paths
provision_workspace;

% Defining color codes to be used 
% in plotting below
mc = fetch_color_codes;

% Pulling out the system information
cfg = auto_fetch_system_information;

% Selecting the default parameter set:
pnames = {'Vp'
          'Vt'
          'CLp'
          'Q'
          'slope_parent'
          'slope_metabolite'};

cfg  = system_select_set(cfg, 'default', pnames);


% Specifying Simulation and Estimation options
%
cfg = system_set_option(cfg, 'simulation', ...
                             'output_times', ...
                              linspace(0,100,10)');

cfg = system_set_option(cfg, 'simulation', 'integrate_with', 'simulink');
cfg = system_set_option(cfg, 'solver',     'solver',         'ode23s');

% To disable the status function uncomment the following line
% cfg = system_set_option(cfg, 'estimation', 'monitor_status_function', '');

% Loading datasets   
%
% From csv        
cfg = system_load_dataset(cfg, 'pmdata' , 'data.csv');


% Defining the cohorts
%
% Clearing all of the cohorts
cfg = system_clear_cohorts(cfg);
%------------------------------------------------------------
% 10 mpk cohort
clear cohort;
cohort.name                                      = 'dose_10';
cohort.cf.DOSE                                   = [10];
cohort.dataset                                   = 'pmdata';
cohort.inputs.bolus.Mpb.AMT                      = [10];
cohort.inputs.bolus.Mpb.TIME                     = [0];
cohort.outputs.parent.obs.time                   = 'TIME'; 
cohort.outputs.parent.obs.value                  = 'PT';
cohort.outputs.parent.obs.missing                = -1;
cohort.outputs.parent.model.time                 = 'hours';        
cohort.outputs.parent.model.value                = 'Cpblood';
cohort.outputs.parent.model.variance             = 'slope_parent*PRED^2'   ;
% Optional                                     
cohort.outputs.parent.options.marker_color       = 'b';
cohort.outputs.parent.options.marker_shape       = 's';
cohort.outputs.parent.options.marker_line        = '-'; 

cohort.outputs.metabolite.obs.time               = 'TIME'; 
cohort.outputs.metabolite.obs.value              = 'MT';
cohort.outputs.metabolite.obs.missing            = -1;
cohort.outputs.metabolite.model.time             = 'hours';        
cohort.outputs.metabolite.model.value            = 'Cmblood';
cohort.outputs.metabolite.model.variance         = 'slope_metabolite*PRED^2'   ;
% Optional
cohort.outputs.metabolite.options.marker_color   = 'b';
cohort.outputs.metabolite.options.marker_shape   = 's';
cohort.outputs.metabolite.options.marker_line    = '-'; 

% Adding the cohort:
cfg = system_define_cohort(cfg, cohort);
%------------------------------------------------------------

%------------------------------------------------------------
% 30 mpk cohort
clear cohort;
cohort.name                                      = 'dose_30';
cohort.cf.DOSE                                   = [30];
cohort.dataset                                   = 'pmdata';
cohort.inputs.bolus.Mpb.AMT                      = [30];
cohort.inputs.bolus.Mpb.TIME                     = [0];
cohort.outputs.parent.obs.time                   = 'TIME'; 
cohort.outputs.parent.obs.value                  = 'PT';
cohort.outputs.parent.obs.missing                = -1;
cohort.outputs.parent.model.time                 = 'hours';        
cohort.outputs.parent.model.value                = 'Cpblood';
cohort.outputs.parent.model.variance             = 'slope_parent*PRED^2'   ;
% Optional                                       
cohort.outputs.parent.options.marker_color       = 'r';
cohort.outputs.parent.options.marker_shape       = 'o';
cohort.outputs.parent.options.marker_line        = '-'; 

cohort.outputs.metabolite.obs.time               = 'TIME'; 
cohort.outputs.metabolite.obs.value              = 'MT';
cohort.outputs.metabolite.obs.missing            = -1;
cohort.outputs.metabolite.model.time             = 'hours';        
cohort.outputs.metabolite.model.value            = 'Cmblood';
cohort.outputs.metabolite.model.variance         = 'slope_metabolite*PRED^2'   ;
% Optional
cohort.outputs.metabolite.options.marker_color   = 'r';
cohort.outputs.metabolite.options.marker_shape   = 's';
cohort.outputs.metabolite.options.marker_line    = '-'; 

% Adding the cohort:
cfg = system_define_cohort(cfg, cohort);
%------------------------------------------------------------


% Getting the parameters either by estimation, loading the previous estimation
% results, or pulling out the initial guess

[pest]=system_estimate_parameters(cfg, flowctl, analysis_name);

% More sample times for generating the predictions
cfg = system_set_option(cfg, 'simulation', ...
                             'output_times', ...
                              linspace(0,100,1000)');

% Running simulation for plotting
[erp] = system_simulate_estimation_results(pest, cfg);


%{
plot_opts.outputs.OUTPUT.panels = 'no';
plot_opts.outputs.OUTPUT.rows   = 1;
plot_opts.outputs.OUTPUT.cols   = 2;
plot_opts.outputs.OUTPUT.yscale = 'log';
plot_opts.outputs.OUTPUT.ylim   = [1,    100];
plot_opts.outputs.OUTPUT.xlim   = [0,    100];
%}

plot_opts.outputs.parent.panels     = 'no' ;
plot_opts.outputs.parent.rows       = 1;
plot_opts.outputs.parent.cols       = 2;
plot_opts.outputs.parent.yscale     = 'log';
plot_opts.outputs.parent.ylim       = [1e-1, 1e3];
plot_opts.outputs.parent.xlim       = [0,    100];


plot_opts.outputs.metabolite.panels = 'no' ;
plot_opts.outputs.metabolite.rows   = 1;
plot_opts.outputs.metabolite.cols   = 2;
plot_opts.outputs.metabolite.yscale = 'log';
plot_opts.outputs.metabolite.ylim   = [1e-1, 1e2];
plot_opts.outputs.metabolite.xlim   = [0,    100];

close all;
system_plot_cohorts(erp, plot_opts, cfg);

