clear; close all;
% compiling the system to make sure the 
% latest changes have been committed. 
build_system;

if(not(isdir('output')))
  mkdir('output');
end

% setting up paths
provision_workspace;

% pulling out the system information
cfg  = auto_fetch_system_information();

% selecting the default parameter set:
cfg  = system_select_set(cfg, 'default');

% fetching the parameter values
parameters = system_fetch_parameters(cfg);

% Overwrite specific defaults
% parameters(cfg.options.mi.parameters.PNAME) = VALUE;

% Setting up bolus events
cfg=system_zero_inputs(cfg);
cfg=system_set_bolus(cfg, 'Cp', ...  % 
                     [ 0  2  4  6], ... % weeks
                     [10 10 10 10]);    % mpk 



% Evaluate system at the following output times
cfg = system_set_option(cfg, 'simulation',   ...
                             'output_times', ...
                             linspace(0,48*24, 200)');

cfg = system_set_option(cfg, 'simulation',     ...
                             'integrate_with', ...
                             'simulink');

cfg = system_set_option(cfg, 'simulation', ...
                             'solver', ...
                             'ode23s');

% getting some predefined color codes
cc = fetch_color_codes;

%-----------------------------------------------
% Stochastic simulations
%
% simulating 100 subjects
cfg  = system_set_option(cfg, 'stochastic', 'nsub', 100);
pred = simulate_subjects(parameters, cfg);

figure(2);
set(gcf, 'Position', [38 63 890 514]);

subplot(2,1,1); hold on;
grid on;
set(gca, 'yscale', 'log')
ylim([.01 2500])
xlim([-1 50]);


ph = patch(pred.times_patch.days,          ...
           pred.outputs_patch.Cp_Total.ci, cc.light_blue, ...
           'linestyle', 'none'); 

ph = patch(pred.times_patch.days,          ...
           pred.outputs_patch.KD_Ind.ci, cc.light_green, ...
           'linestyle', 'none'); 

plot(pred.times.days,          ...
     pred.outputs_stats.Cp_Total.mean, 'b-')
plot(pred.times.days,          ...
     pred.outputs_stats.Cp_Total.lb_ci, 'b-.')
plot(pred.times.days,          ...
     pred.outputs_stats.Cp_Total.ub_ci, 'b-.')


plot(pred.times.days,          ...
     pred.outputs_stats.KD_Ind.mean, '-', 'color', cc.dark_green)
plot(pred.times.days,          ...
     pred.outputs_stats.KD_Ind.lb_ci, '-.', 'color', cc.dark_green)
plot(pred.times.days,          ...
     pred.outputs_stats.KD_Ind.ub_ci, '-.', 'color', cc.dark_green)

      prepare_figure('present');
ylabel('Total Drug and KD (nM)');

subplot(2,1,2); hold on;
grid on;
ylim([0.5 1.01])
xlim([-1 50]);

ph = patch(pred.times_patch.days,          ...
           pred.outputs_patch.Coverage.ci, cc.light_blue, ...
           'linestyle', 'none'); 

plot(pred.times.days,          ...
     pred.outputs_stats.Coverage.mean, 'b-')
plot(pred.times.days,          ...
     pred.outputs_stats.Coverage.lb_ci, 'b-.')
plot(pred.times.days,          ...
     pred.outputs_stats.Coverage.ub_ci, 'b-.')

      prepare_figure('present');
ylabel('Fractional Target Coverage');
xlabel('Time (days)');

dump_figure(sprintf('output%ssimulation_example-coverage_stochastic', filesep));
%-----------------------------------------------



