clear; close all;
% compiling the system to make sure the 
% latest changes have been committed. 
build_system;

if(not(isdir('output')))
  mkdir('output');
end

% setting up paths
provision_workspace;

% pulling out the system information
cfg  = auto_fetch_system_information();

% selecting the default parameter set:
cfg  = system_select_set(cfg, 'default');

% fetching the parameter values
parameters = system_fetch_parameters(cfg);

% Overwrite specific defaults
% parameters(cfg.options.mi.parameters.PNAME) = VALUE;

% Setting up bolus events
cfg=system_zero_inputs(cfg);
cfg=system_set_bolus(cfg, 'Cp', ...  % 
                     [ 0  2  4  6], ... % weeks
                     [10 10 10 10]);    % mpk 



% Evaluate system at the following output times
cfg = system_set_option(cfg, 'simulation',   ...
                             'output_times', ...
                             linspace(0,48*24, 200)');

cfg = system_set_option(cfg, 'simulation',     ...
                             'integrate_with', ...
                             'simulink');

cfg = system_set_option(cfg, 'simulation', ...
                             'solver', ...
                             'ode23s');

% getting some predefined color codes
cc = fetch_color_codes;


%-----------------------------------------------
% Individual simulations
%
% simulating the response
som = run_simulation_ubiquity(parameters, cfg);

close all
figure(1);
set(gcf, 'Position', [38 63 890 514]);
subplot(2,1,1); hold on;
grid on;
set(gca, 'yscale', 'log')
ylim([.01 2500])
xlim([-1 50]);
plot(som.times.days,  som.outputs.Cp_Total, 'b-');
plot(som.times.days,  som.outputs.KD_Ind,  '-', 'color', cc.dark_green);
prepare_figure('present');
ylabel('Total Drug and KD (nM)');

subplot(2,1,2); hold on;
grid on;
ylim([0.5 1.01])
xlim([-1 50]);
plot(som.times.days, som.outputs.Coverage, 'b-')
prepare_figure('present');
ylabel('Fractional Target Coverage');
xlabel('Time (days)');
dump_figure(sprintf('output%ssimulation_example-coverage_individual', filesep));
%-----------------------------------------------
